package com.vendor.burn.utilitily;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.Activator;
import com.vendor.burn.log.Log;
import com.vendor.burn.model.PartitionItem;
import com.vendor.burn.model.ProductLine;
import com.vendor.burn.model.TransferWay;
import com.vendor.burn.model.config.PreferenceConfig;
import com.vendor.burn.model.devices.unknown.UnknownDevice;
import com.vendor.burn.preferences.FastbootPreferences;
import com.vendor.burn.utilitily.JarUtility;
import com.vendor.burn.views.CmdMain;
import com.vendor.burn.views.FastbootView;
import com.vendor.platform.api.IDeviceManager;
import com.vendor.platform.api.chips.Chip;
import com.vendor.platform.api.chips.Tool;
import com.vendor.platform.ui.internal.IniUtils;
import java.io.File;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.Element;
import org.dom4j.io.SAXReader;
import org.eclipse.core.runtime.Platform;
import org.eclipse.swt.layout.GridData;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.xml.sax.SAXException;

public class ToolUtils {
  public static final String PRODUCTLINESSTR = "Chip";
  
  public static final String ID = "id";
  
  public static final String TOOLREFNAME = "BurnTool";
  
  public static final String NAME = "name";
  
  public static final String PRODUCTIONLINE = "productionLine";
  
  public static final String PARAM = "param";
  
  public static final String TOOLREF = "Tool";
  
  public static final String CHIP = "Chip";
  
  public static final String JAVAHEASPACE = "Java heap space";
  
  public static final String ALLHOSTADDRESS = "x.x.x.x";
  
  public static final int SINGLESIZE = 1048576;
  
  private static final String DEFAULT_TFTP_PORT_CMD = "cmd.exe /c netstat -aon|findstr :";
  
  private static final String DEFAULT_TFTP_PORT_LINUX_CMD = "/bin/sh -c netstat -tunlp|grep :";
  
  private static boolean isCmdLine = false;
  
  private static boolean isSetGsl = false;
  
  private static List<String> barredEarsePartition = Arrays.asList(new String[] { "batt_nv" });
  
  public static List<PartitionItem> removeNoEarsePart(List<PartitionItem> partitionItems) {
    if (partitionItems == null || partitionItems.size() <= 0)
      return partitionItems; 
    List<PartitionItem> parts = new ArrayList<>();
    for (int i = 0; i < partitionItems.size(); i++) {
      PartitionItem part = partitionItems.get(i);
      if (part.getName() == null || !barredEarsePartition.contains(part.getName()) || part
        .getFile() != null || !part.isChecked())
        parts.add(part); 
    } 
    return parts;
  }
  
  public static String getInstallPath() {
    if (isCmdLine()) {
      String jarDir = JarUtility.getJarDir();
      if (jarDir != null) {
        if (!jarDir.endsWith(File.separator))
          jarDir = jarDir.concat(File.separator); 
        return jarDir;
      } 
      Log.errorln("jar path is null.");
      return null;
    } 
    String path = Platform.getInstallLocation().getURL().getPath();
    if (path.startsWith("//"))
      return path; 
    if (path.startsWith("/")) {
      String osName = System.getProperties().getProperty("os.name");
      if (osName.toLowerCase().startsWith("windows")) {
        path = path.substring(1);
      } else {
        if (osName.toLowerCase().startsWith("linux"))
          return path; 
        path = path.substring(1);
      } 
    } 
    return path;
  }
  
  public static Locale getCurrentLocale() {
    String nl = IniUtils.getIniConfiguration("osgi.nl");
    if (nl.length() == 0)
      nl = Locale.getDefault().toString(); 
    if (nl.equals(Locale.US.toString()))
      return Locale.US; 
    if (nl.equals(Locale.SIMPLIFIED_CHINESE.toString()))
      return Locale.SIMPLIFIED_CHINESE; 
    return Locale.getDefault();
  }
  
  public static String getChipNameType() {
    return FastbootView.getCurrentChipNameType();
  }
  
  public static String getChipName() {
    if (isCmdLine())
      return CmdMain.getChipName(); 
    BundleContext bundleContext = Activator.getDefault().getBundle().getBundleContext();
    ServiceReference<?> sreference = bundleContext.getServiceReference(IDeviceManager.class);
    if (sreference == null)
      return ""; 
    IDeviceManager deviceManager = (IDeviceManager)bundleContext.getService(sreference);
    return deviceManager.getCurrentDevice();
  }
  
  public static String getLibbootromPath(boolean isUnifyLibBurn) {
    String osName = System.getProperties().getProperty("os.name");
    String path = "";
    String dllPath = "dll64";
    if (isUnifyLibBurn)
      dllPath = "unifyLibBurn"; 
    String installPath = getInstallPath() + "Resources" + getInstallPath() + "Common" + File.separator + File.separator + dllPath;
    if (osName.toLowerCase(Locale.ENGLISH).startsWith("windows")) {
      path = installPath + "libburn.dll";
    } else {
      path = installPath + "libburn.so";
    } 
    return path;
  }
  
  public static void setWidthForOS(GridData gridData, int windowsWidth, int linuxWidth) {
    if (isLinux()) {
      gridData.widthHint = linuxWidth;
    } else {
      gridData.widthHint = windowsWidth;
    } 
  }
  
  public static ProductLine.PRODUCTLINE getProductLine() {
    String ChinName = getChipName();
    UnknownDevice properties = new UnknownDevice(ChinName);
    String type = properties.queryForString("TYPE");
    if (type == null)
      return ProductLine.PRODUCTLINE.STB; 
    if (type.equalsIgnoreCase(ProductLine.PRODUCTLINE.STB.toString()))
      return ProductLine.PRODUCTLINE.STB; 
    if (type.equalsIgnoreCase(ProductLine.PRODUCTLINE.CAM.toString()))
      return ProductLine.PRODUCTLINE.CAM; 
    return ProductLine.PRODUCTLINE.TV;
  }
  
  public static long getSplitFileSize() {
    if (isCmdLine())
      return (PreferenceConfig.getTftpSplitFileSize() * 1048576); 
    return (FastbootPreferences.getInt("vendor.burn.split.fileSize") * 1048576);
  }
  
  public static String getPortCmd() {
    String osName = System.getProperties().getProperty("os.name");
    if (osName.toLowerCase().startsWith("windows"))
      return "cmd.exe /c netstat -aon|findstr :"; 
    if (osName.toLowerCase().startsWith("linux"))
      return "/bin/sh -c netstat -tunlp|grep :"; 
    return "/bin/sh -c netstat -tunlp|grep :";
  }
  
  public static boolean isJTagTransferMode(TransferWay transferWay) {
    return (transferWay == TransferWay.JTAG || transferWay == TransferWay.JTAGAndNet || transferWay == TransferWay.JTAGAndSerial);
  }
  
  public static boolean isLinux() {
    String osName = System.getProperties().getProperty("os.name");
    if (osName.toLowerCase().startsWith("linux"))
      return true; 
    return false;
  }
  
  public static boolean isDebugOn() {
    if (isCmdLine())
      return PreferenceConfig.isDebugPrint(); 
    return FastbootPreferences.isDebugOn();
  }
  
  public static boolean isCmdLine() {
    return isCmdLine;
  }
  
  public static void setCmdLine(boolean isCmdLine) {
    com.vendor.burn.utilitily.ToolUtils.isCmdLine = isCmdLine;
  }
  
  public static List<Chip> getChip(String pathName) {
    return getChipByProductLineId(pathName);
  }
  
  public static List<Chip> getChipByProductLineId(String pathName) {
    File file = new File(pathName);
    SAXReader reader = new SAXReader();
    try {
      reader.setFeature("http://apache.org/xml/features/disallow-doctype-decl", true);
    } catch (SAXException sAXException) {}
    Document doc = null;
    try {
      doc = reader.read(file);
    } catch (DocumentException documentException) {}
    ArrayList<Chip> chips = new ArrayList<>();
    if (doc == null)
      return chips; 
    Element root = doc.getRootElement();
    List<Element> productLines = getElementListByName("Chip", root);
    if (productLines == null)
      return chips; 
    getChipByElement(chips, productLines);
    return chips;
  }
  
  private static void getChipByElement(ArrayList<Chip> chips, List<Element> productLines) {
    for (Element element : productLines) {
      if (element == null)
        continue; 
      Chip chip = new Chip();
      String chipId = element.attributeValue("id");
      String chipName = element.attributeValue("name");
      String productLineId = element.attributeValue("productionLine");
      chip.setId(chipId);
      chip.setName(chipName);
      chip.setProductionLine(productLineId);
      List<Element> toolRefList = getElementListByName("Tool", element);
      if (toolRefList == null)
        continue; 
      ArrayList<Tool> tools = new ArrayList<>();
      for (Element toolRef : toolRefList) {
        String toolRefId = toolRef.attributeValue("id");
        Tool tool = new Tool();
        String toolRefParam = toolRef.attributeValue("param");
        tool.setParam(toolRefParam);
        tool.setId(toolRefId);
        tools.add(tool);
      } 
      chip.setToolList(tools);
      chips.add(chip);
    } 
  }
  
  private static List<Element> getElementListByName(String elementName, Element element) {
    if (elementName == null || element == null)
      return null; 
    List<Element> elementList = new ArrayList<>();
    for (Iterator<Element> i = element.elementIterator(elementName); i.hasNext();)
      elementList.add(i.next()); 
    return elementList;
  }
  
  public static boolean isSetGsl() {
    return isSetGsl;
  }
  
  public static void setSetGsl(boolean isSetGsl) {
    com.vendor.burn.utilitily.ToolUtils.isSetGsl = isSetGsl;
  }
  
  public static void disableDetach(String pageId) {
    com.vendor.platform.ui.ToolUtils.disableDetach(pageId);
  }
}
